@@ -2,6 +2,7 @@ package Net::Server::Mail;
 
 use 5.006;
 use strict;
+use warnings;
 use Sys::Hostname;
 use IO::Select;
 use IO::Handle;
@@ -9,7 +10,7 @@ use Carp;
 
 use constant HOSTNAME => hostname();
 
-$Net::Server::Mail::VERSION = '0.22';
+$Net::Server::Mail::VERSION = '0.24';
 
 =pod
 
@@ -22,16 +23,16 @@ Net::Server::Mail - Class to easily create a mail server
     use Net::Server::Mail::SMTP;
 
     my @local_domains = qw(example.com example.org);
-    my $server = new IO::Socket::INET Listen => 1, LocalPort => 25;
+    my $server = IO::Socket::INET->new( Listen => 1, LocalPort => 25 );
     
     my $conn;
     while($conn = $server->accept)
     {
-        my $smtp = new Net::Server::Mail::SMTP socket => $conn;
+        my $smtp = Net::Server::Mail::SMTP->new( socket => $conn );
         $smtp->set_callback(RCPT => \&validate_recipient);
         $smtp->set_callback(DATA => \&queue_message);
         $smtp->process();
-	$conn->close();
+        $conn->close();
     }
 
     sub validate_recipient
@@ -39,7 +40,7 @@ Net::Server::Mail - Class to easily create a mail server
         my($session, $recipient) = @_;
         
         my $domain;
-        if($recipient =~ /@(.*)>\s*$/)
+        if($recipient =~ /\@(.*)>\s*$/)
         {
             $domain = $1;
         }
@@ -66,7 +67,7 @@ Net::Server::Mail - Class to easily create a mail server
         return(0, 554, 'Error: no valid recipients')
             unless(@recipients);
         
-        my $msgid = add_queue($sender, \@recipients, $data);
+        my $msgid = add_queue($sender, \@recipients, $data)
           or return(0);
 
         return(1, 250, "message queued $msgid");
@@ -98,7 +99,7 @@ each of these modules.
 
 =head2 new
 
-    $instance = new Net::Server::Mail [option => 'value', ...]
+    $instance = Net::Server::Mail->new( [option => 'value', ...] )
 
 options:
 
@@ -213,8 +214,7 @@ sub make_event {
     my %args = @_;
 
     my $name = $args{'name'} || confess('missing argument: \'name\'');
-    my $args =
-      defined $args{'arguments'}
+    my $args = defined $args{'arguments'}
       && ref $args{'arguments'} eq 'ARRAY' ? $args{'arguments'} : [];
 
     $self->init_dojob();
@@ -268,7 +268,8 @@ sub make_event {
         }
     }
 
-    die "return code `$code' isn't numeric" if ( defined $code && $code =~ /\D/ );
+    die "return code `$code' isn't numeric"
+      if ( defined $code && $code =~ /\D/ );
 
     $self->handle_reply( $name, $success, $code, $msg )
       if defined $code and length $code;
@@ -418,7 +419,7 @@ sub process {
     my ($self) = @_;
 
     my $in  = $self->{in};
-    my $sel = new IO::Select;
+    my $sel = IO::Select->new;
     $sel->add($in);
 
     $self->banner;
@@ -455,15 +456,17 @@ sub process {
                 $rv = sysread( $in, $buffer, 512 * 1024, length($buffer) );
             }
         }
-	else {
-	    # timeout
-	    return $self->timeout;
-	}
+        else {
+            # timeout
+            return $self->timeout;
+        }
 
+        next
+          if ( not defined $rv and $! =~ /Resource temporarily unavailable/ );
         if ( ( not defined $rv ) or ( $rv == 0 ) ) {
 
             # read error or connection closed
-            return $self->stop_session((not defined $rv) ? ($!) : ());
+            return $self->stop_session( ( not defined $rv ) ? ($!) : () );
         }
 
         # process all terminated lines
@@ -677,7 +680,7 @@ sub timeout {
 
 This event append where connection is closed or an error occurs during reading from socket.
 
-Takes the error description as an argument if an error occured and the argument is undefined if the session was closed by peer.
+Takes the error description as an argument if an error occurred and the argument is undefined if the session was closed by peer.
 
     $mailserver->set_callback
     (
@@ -686,7 +689,7 @@ Takes the error description as an argument if an error occured and the argument
             my($session, $err) = @_;
             if( defined $err )
             {
-                print "Error occured during processing: $err\n";
+                print "Error occurred during processing: $err\n";
             }
             else
             {
@@ -699,12 +702,12 @@ Takes the error description as an argument if an error occured and the argument
 =cut
 
 sub stop_session {
-    my ($self, $err) = @_;
+    my ( $self, $err ) = @_;
 
     $self->make_event(
-        name          => 'stop_session',
-	arguments     => [$err],
-	no_reply      => 1,
+        name      => 'stop_session',
+        arguments => [$err],
+        no_reply  => 1,
     );
 
     return 1;
