@@ -2,28 +2,29 @@ package Net::Server::Mail::ESMTP;
 
 use 5.006;
 use strict;
+use warnings;
 use Carp;
 use base qw(Net::Server::Mail::SMTP);
 
-our $VERSION = "0.16";
+our $VERSION = "0.24";
 
 =pod
 
 =head1 NAME
 
-Net::Server::Mail::ESMTP - A module to implement the ESMTP protocole
+Net::Server::Mail::ESMTP - A module to implement the ESMTP protocol
 
 =head1 SYNOPSIS
 
     use Net::Server::Mail::ESMTP;
 
     my @local_domains = qw(example.com example.org);
-    my $server = new IO::Socket::INET Listen => 1, LocalPort => 25;
+    my $server = IO::Socket::INET->new( Listen => 1, LocalPort => 25 );
 
     my $conn;
     while($conn = $server->accept)
     {
-        my $esmtp = new Net::Server::Mail::ESMTP socket => $conn;
+        my $esmtp = Net::Server::Mail::ESMTP->new( socket => $conn );
         # activate some extensions
         $esmtp->register('Net::Server::Mail::ESMTP::8BITMIME');
         $esmtp->register('Net::Server::Mail::ESMTP::PIPELINING');
@@ -31,7 +32,7 @@ Net::Server::Mail::ESMTP - A module to implement the ESMTP protocole
         $esmtp->set_callback(RCPT => \&validate_recipient);
         $esmtp->set_callback(DATA => \&queue_message);
         $esmtp->process();
-	$conn->close()
+        $conn->close();
     }
 
     sub validate_recipient
@@ -39,7 +40,7 @@ Net::Server::Mail::ESMTP - A module to implement the ESMTP protocole
         my($session, $recipient) = @_;
 
         my $domain;
-        if($recipient =~ /@(.*)>\s*$/)
+        if($recipient =~ /\@(.*)>\s*$/)
         {
             $domain = $1;
         }
@@ -85,28 +86,25 @@ ESMTP specific methods.
 
 =cut
 
-sub init
-{
-    my($self, @args) = @_;
+sub init {
+    my ( $self, @args ) = @_;
     my $rv = $self->SUPER::init(@args);
     return $rv unless $rv eq $self;
 
-    $self->def_verb(EHLO => 'ehlo');
+    $self->def_verb( EHLO => 'ehlo' );
 
     $self->{extend_mode} = 0;
 
     return $self;
 }
 
-sub get_protoname
-{
+sub get_protoname {
     return 'ESMTP';
 }
 
-sub get_extensions
-{
-    my($self) = @_;
-    return(@{$self->{extensions} || []});
+sub get_extensions {
+    my ($self) = @_;
+    return ( @{ $self->{extensions} || [] } );
 }
 
 =pod
@@ -119,64 +117,57 @@ L<Net::Server::Mail::ESMTP::Extension> for more details.
 
 =cut
 
-sub register
-{
-    my($self, $class) = @_;
+sub register {
+    my ( $self, $class ) = @_;
+
     # try to import class
     eval "require $class" or croak("can't register module `$class'");
+
     # test mandatory methods
-    foreach my $method (qw(new verb keyword parameter option reply))
-    {
-        confess("Extension class `$class' doesn't implement mandatory method `$method'")
-            unless($class->can($method));
+    foreach my $method (qw(new verb keyword parameter option reply)) {
+        confess(
+"Extension class `$class' doesn't implement mandatory method `$method'"
+        ) unless ( $class->can($method) );
     }
 
-    my $extend = new $class $self or return;
-    foreach my $verb_def ($extend->verb)
-    {
+    my $extend = $class->new($self) or return;
+    foreach my $verb_def ( $extend->verb ) {
         $self->def_verb(@$verb_def) or return;
     }
 
-    foreach my $option_def ($extend->option)
-    {
+    foreach my $option_def ( $extend->option ) {
         $self->sub_option(@$option_def);
     }
 
-    foreach my $reply_def ($extend->reply)
-    {
+    foreach my $reply_def ( $extend->reply ) {
         $self->sub_reply(@$reply_def);
     }
 
-    push(@{$self->{extensions}}, $extend);
+    push( @{ $self->{extensions} }, $extend );
     return 1;
 }
 
-sub sub_option
-{
-    my($self, $verb, $option_key, $code) = @_;
+sub sub_option {
+    my ( $self, $verb, $option_key, $code ) = @_;
     confess("can't subscribe to option for verb `$verb'")
-        unless($verb eq 'MAIL' or $verb eq 'RCPT');
+      unless ( $verb eq 'MAIL' or $verb eq 'RCPT' );
     confess("allready subscribed `$option_key'")
-        if(exists $self->{xoption}->{$verb}->{$option_key});
+      if ( exists $self->{xoption}->{$verb}->{$option_key} );
     $self->{xoption}->{$verb}->{$option_key} = $code;
 }
 
-sub sub_reply
-{
-    my($self, $verb, $code) = @_;
+sub sub_reply {
+    my ( $self, $verb, $code ) = @_;
     confess("trying to subscribe to an unsupported verb `$verb'")
-        unless(grep($verb eq $_, $self->list_verb));
-    push(@{$self->{xreply}->{$verb}}, $code);
+      unless ( grep( $verb eq $_, $self->list_verb ) );
+    push( @{ $self->{xreply}->{$verb} }, $code );
 }
 
-sub extend_mode
-{
-    my($self, $mode) = @_;
+sub extend_mode {
+    my ( $self, $mode ) = @_;
     $self->{extend_mode} = $mode;
-    for my $extend (@{$self->{extensions}})
-    {
-        if($extend->can('extend_mode'))
-        {
+    for my $extend ( @{ $self->{extensions} } ) {
+        if ( $extend->can('extend_mode') ) {
             $extend->extend_mode($mode);
         }
     }
@@ -193,7 +184,7 @@ argument and specific callback's arguments.
 =head2 EHLO
 
 Takes the hostname given as argument. Engage the reverse path step on
-success. RFC 2821 require thats EHLO command return the list of
+success. RFC 2821 requires that EHLO command return the list of
 supported extension. Default success reply implement this, so it is
 deprecated to override this reply.
 
@@ -210,92 +201,79 @@ Exemple:
 
 =cut
 
-sub ehlo
-{
-    my($self, $hostname) = @_;
+sub ehlo {
+    my ( $self, $hostname ) = @_;
 
-    unless(defined $hostname && length $hostname)
-    {
-        $self->reply(501, 'Syntax error in parameters or arguments');
+    unless ( defined $hostname && length $hostname ) {
+        $self->reply( 501, 'Syntax error in parameters or arguments' );
         return;
     }
 
     my $response = $self->get_hostname . ' Service ready';
 
     my @extends;
-    foreach my $extend ($self->get_extensions)
-    {
-        push(@extends, join(' ', $extend->keyword, $extend->parameter));
+    foreach my $extend ( $self->get_extensions ) {
+        push( @extends, join( ' ', $extend->keyword, $extend->parameter ) );
     }
 
     $self->extend_mode(1);
-    $self->make_event
-    (
-        name => 'EHLO',
-        arguments => [$hostname, \@extends],
-        on_success => sub
-        {
+    $self->make_event(
+        name       => 'EHLO',
+        arguments  => [ $hostname, \@extends ],
+        on_success => sub {
+
             # according to the RFC, EHLO ensures "that both the SMTP client
             # and the SMTP server are in the initial state"
             $self->step_reverse_path(1);
             $self->step_forward_path(0);
             $self->step_maildata_path(0);
         },
-        success_reply => [250, [$response, @extends]],
+        success_reply => [ 250, [ $response, @extends ] ],
     );
 
     return;
 }
 
-sub helo
-{
-    my($self, $hostname) = @_;
+sub helo {
+    my ( $self, $hostname ) = @_;
     $self->{extend_mode} = 0;
     $self->SUPER::helo($hostname);
 }
 
-sub handle_options
-{
-    my($self, $verb, $address, @options) = @_;
+sub handle_options {
+    my ( $self, $verb, $address, @options ) = @_;
 
-    if(@options && !$self->{extend_mode})
-    {
-        $self->reply(555, "Unsupported option: $options[0]");
+    if ( @options && !$self->{extend_mode} ) {
+        $self->reply( 555, "Unsupported option: $options[0]" );
         return 0;
     }
 
-    for(my $i = $#options; $i >= 0; $i--)
-    {
-        my($key, $value) = split(/=/, $options[$i], 2);
+    for ( my $i = $#options ; $i >= 0 ; $i-- ) {
+        my ( $key, $value ) = split( /=/, $options[$i], 2 );
         my $handler = $self->{xoption}->{$verb}->{$key};
-        if(defined $handler)
-        {
+        if ( defined $handler ) {
             no strict "refs";
-            &$handler($self, $verb, $address, $key, $value);
+            &$handler( $self, $verb, $address, $key, $value );
         }
-        else
-        {
-            $self->reply(555, "Unsupported option: $key");
+        else {
+            $self->reply( 555, "Unsupported option: $key" );
             return 0;
         }
     }
-    
+
     return 1;
 }
 
-sub handle_reply
-{
-    my($self, $verb, $success, $code, $msg) = @_;
+sub handle_reply {
+    my ( $self, $verb, $success, $code, $msg ) = @_;
 
-    if($self->{extend_mode} && exists $self->{xreply}->{$verb})
-    {
-        foreach my $handler (@{$self->{xreply}->{$verb}})
-        {
-            ($code, $msg) = &$handler($self, $verb, $success, $code, $msg);
+    if ( $self->{extend_mode} && exists $self->{xreply}->{$verb} ) {
+        foreach my $handler ( @{ $self->{xreply}->{$verb} } ) {
+            ( $code, $msg ) = &$handler( $self, $verb, $success, $code, $msg );
         }
     }
 
-    $self->reply($code, $msg);
+    $self->reply( $code, $msg );
 }
 
 =pod
@@ -313,13 +291,13 @@ Olivier Poitrey E<lt>rs@rhapsodyk.netE<gt>
 
 Available on CPAN.
 
-anonymous SVN repository:
+anonymous Git repository:
 
-svn co https://emailproject.perl.org/svn/Net-Server-Mail
+git clone git://github.com/rs/net-server-mail.git
 
-SVN repository on the web:
+Git repository on the web:
 
-http://emailproject.perl.org/svn/Net-Server-Mail/
+L<https://github.com/rs/net-server-mail>
 
 =head1 BUGS
 
