@@ -2,8 +2,9 @@ package Net::Server::Mail::ESMTP::Extension;
 
 use 5.006;
 use strict;
+use warnings;
 
-our $VERSION = "0.14";
+our $VERSION = "0.24";
 
 =pod
 
@@ -15,12 +16,11 @@ Net::Server::Mail::ESMTP::Extension - The base class for ESMTP extension system
 
 =cut
 
-sub new
-{
-    my($proto, $parent) = @_;
-    my $class  = ref $proto || $proto;
-    my $self   = {};
-    bless($self, $class);
+sub new {
+    my ( $proto, $parent ) = @_;
+    my $class = ref $proto || $proto;
+    my $self = {};
+    bless( $self, $class );
     return $self->init($parent);
 }
 
@@ -35,9 +35,8 @@ initialisation. The method takes the $smtp object as parameter.
 
 =cut
 
-sub init
-{
-    my($self, $parent) = @_;
+sub init {
+    my ( $self, $parent ) = @_;
     return $self;
 }
 
@@ -47,8 +46,7 @@ sub init
 
 =cut
 
-sub verb
-{
+sub verb {
     return ();
 }
 
@@ -58,8 +56,7 @@ sub verb
 
 =cut
 
-sub keyword
-{
+sub keyword {
     return 'XNOTOVERLOADED';
 }
 
@@ -69,8 +66,7 @@ sub keyword
 
 =cut
 
-sub parameter
-{
+sub parameter {
     return ();
 }
 
@@ -80,8 +76,7 @@ sub parameter
 
 =cut
 
-sub option
-{
+sub option {
     return ();
 }
 
@@ -91,8 +86,7 @@ sub option
 
 =cut
 
-sub reply
-{
+sub reply {
     return ();
 }
 
