@@ -19,7 +19,7 @@ use IO::Socket::SSL 1.831;
 use Net::Server::Mail::ESMTP::Extension;
 our @ISA = qw(Net::Server::Mail::ESMTP::Extension);
 
-our $VERSION = 0.21;
+our $VERSION = 0.24;
 
 use constant {
     REPLY_READY_TO_START => 220,
@@ -94,12 +94,12 @@ Net::Server::Mail::ESMTP::STARTTLS - A module to support the STARTTLS command in
    use Net::Server::Mail::ESMTP;
 
    my @local_domains = qw(example.com example.org);
-   my $server = new IO::Socket::INET Listen => 1, LocalPort => 25;
+   my $server = IO::Socket::INET->new( Listen => 1, LocalPort => 25 );
 
    my $conn;
    while($conn = $server->accept)
    {
-       my $esmtp = new Net::Server::Mail::ESMTP(
+       my $esmtp = Net::Server::Mail::ESMTP->new(
             socket => $conn,
             SSL_config => {
                 SSL_cert_file => 'your_cert.pem',
@@ -114,7 +114,7 @@ Net::Server::Mail::ESMTP::STARTTLS - A module to support the STARTTLS command in
        # adding optional STARTTLS handler
        $esmtp->set_callback(STARTTLS => \&tls_started);
        $esmtp->process();
-       $conn->close()
+       $conn->close();
    }
    
    sub tls_started {
@@ -141,7 +141,7 @@ Please, see L<Net::Server::Mail>
 
 =head1 AUTHOR
 
-This module has been writed by Xavier Guimard <x.guimard@free.fr> using libs
+This module has been written by Xavier Guimard <x.guimard@free.fr> using libs
 written by:
 
 =over
