@@ -4,13 +4,13 @@ use 5.006;
 use strict;
 use base qw(Net::Server::Mail::ESMTP);
 
-our $VERSION = "0.16";
+our $VERSION = "0.24";
 
 =pod
 
 =head1 NAME
 
-Net::Server::Mail::LMTP - A module to implement the LMTP protocole
+Net::Server::Mail::LMTP - A module to implement the LMTP protocol
   
 
 =head1 SYNOPSIS
@@ -18,17 +18,17 @@ Net::Server::Mail::LMTP - A module to implement the LMTP protocole
     use Net::Server::Mail::LMTP;
 
     my @local_domains = qw(example.com example.org);
-    my $server = new IO::Socket::INET Listen => 1, LocalPort => 25;
+    my $server = IO::Socket::INET->new( Listen => 1, LocalPort => 25 );
 
     my $conn;
     while($conn = $server->accept)
     {
-        my $esmtp = new Net::Server::Mail::LMTP socket => $conn;
+        my $esmtp = Net::Server::Mail::LMTP->new( socket => $conn );
         # adding some handlers
         $esmtp->set_callback(RCPT => \&validate_recipient);
         $esmtp->set_callback(DATA => \&queue_message);
         $esmtp->process();
-	$conn->close()
+        $conn->close();
     }
 
     sub validate_recipient
@@ -36,7 +36,7 @@ Net::Server::Mail::LMTP - A module to implement the LMTP protocole
         my($session, $recipient) = @_;
 
         my $domain;
-        if($recipient =~ /@(.*)>\s*$/)
+        if($recipient =~ /\@(.*)>\s*$/)
         {
             $domain = $1;
         }
@@ -78,16 +78,15 @@ L<Net::Server::Mail::ESMTP> for documentation of common methods.
 
 =cut
 
-sub init
-{
-    my($self, @args) = @_;
+sub init {
+    my ( $self, @args ) = @_;
     my $rv = $self->SUPER::init(@args);
     return $rv unless $rv eq $self;
 
     $self->undef_verb('HELO');
     $self->undef_verb('EHLO');
 
-    $self->def_verb(LHLO => 'lhlo');
+    $self->def_verb( LHLO => 'lhlo' );
 
     # Required by RFC
     $self->register('Net::Server::Mail::ESMTP::PIPELINING');
@@ -95,8 +94,7 @@ sub init
     return $self;
 }
 
-sub get_protoname
-{
+sub get_protoname {
     return 'LMTP';
 }
 
@@ -114,31 +112,27 @@ Same as ESMTP EHLO, please see L<Net::Server::Mail::ESMTP>.
 
 =cut
 
-sub lhlo
-{
-    my($self, $hostname) = @_;
+sub lhlo {
+    my ( $self, $hostname ) = @_;
 
-    unless(defined $hostname && length $hostname)
-    {
-        $self->reply(501, 'Syntax error in parameters or arguments');
+    unless ( defined $hostname && length $hostname ) {
+        $self->reply( 501, 'Syntax error in parameters or arguments' );
         return;
     }
 
     my $response = $self->get_hostname . ' Service ready';
 
     my @extends;
-    foreach my $extend ($self->get_extensions)
-    {
-        push(@extends, join(' ', $extend->keyword, $extend->parameter));
+    foreach my $extend ( $self->get_extensions ) {
+        push( @extends, join( ' ', $extend->keyword, $extend->parameter ) );
     }
 
     $self->extend_mode(1);
-    $self->make_event
-    (
-        name => 'LHLO',
-        arguments => [$hostname, \@extends],
-        on_success => sub
-        {
+    $self->make_event(
+        name       => 'LHLO',
+        arguments  => [ $hostname, \@extends ],
+        on_success => sub {
+
             # according to the RFC, LHLO ensures "that both the SMTP client
             # and the SMTP server are in the initial state"
             $self->{extend_mode} = 1;
@@ -146,7 +140,7 @@ sub lhlo
             $self->step_forward_path(0);
             $self->step_maildata_path(0);
         },
-        success_reply => [250, [$response, @extends]],
+        success_reply => [ 250, [ $response, @extends ] ],
     );
 
     return;
@@ -162,29 +156,59 @@ first argument followed by the current recipient.
 
 =cut
 
-sub data_finished
-{
-    my($self) = @_;
-    
-    my $recipients = $self->step_forward_path();
+sub data {
+    my ( $self, $args ) = @_;
 
-    foreach my $forward_path (@$recipients)
+    unless ( ref $self->step_forward_path eq 'ARRAY'
+        and @{ $self->step_forward_path } )
     {
-        $self->make_event
-        (
-            name => 'DATA',
-            arguments => [\$self->{_data}, $forward_path],
-            success_reply => [250, 'Ok'],
-            failure_reply => [550, "$forward_path Failed"],
+        $self->reply( 503, 'Bad sequence of commands' );
+        return;
+    }
+    $self->SUPER::data($args);
+}
+
+sub data_finished {
+    my ( $self, $more_data ) = @_;
+
+    my @recipients = @{ $self->step_forward_path || [] };
+
+    $self->{continuous_reply} = 1;
+    while ( my $forward_path = shift @recipients ) {
+        $self->{continuous_reply} = 0 unless @recipients;
+        $self->make_event(
+            name          => 'DATA',
+            arguments     => [ \$self->{_data}, $forward_path ],
+            success_reply => [ 250, 'Ok' ],
+            failure_reply => [ 550, "$forward_path Failed" ],
         );
     }
+    $self->{continuous_reply} = 0;
 
     # reinitiate the connection
     $self->step_reverse_path(1);
     $self->step_forward_path(0);
     $self->step_maildata_path(0);
 
-    return;
+    # if more data, handle it
+    if ($more_data) {
+        return $self->{process_operation}( $self, $more_data );
+    }
+    else {
+        return;
+    }
+}
+
+sub reply {
+    my ( $self, $code, $msg ) = @_;
+
+    if ( not ref $msg and $self->{continuous_reply} ) {
+        my $out = $self->{out};
+        print $out "$code-$msg\r\n";
+    }
+    else {
+        $self->SUPER::reply( $code, $msg );
+    }
 }
 
 =pod
